/**! @qoopido/validator 1.3.1 | https://github.com/dlueth/qoopido | (c) 2021 Dirk Lueth */
/**
 * Check if value is of a certain type
 *
 * @param {*} value
 * @param {String} type
 *
 * @returns {Boolean}
 */
function isTypeof(value, type) {
    return typeof value === type;
}

/**
 * Check if value is of a certain type
 *
 * @param {*} value
 * @param {*} constructor
 *
 * @returns {Boolean}
 */
function isInstanceof(value, constructor) {
    return value instanceof constructor;
}

/**
 * Check if value is a string
 *
 * @param {*} value
 *
 * @returns {Boolean}
 */
function isString(value) {
    return isTypeof(value, "string") || isInstanceof(value, String);
}

var regexMatchSemver =
    /^\bv?(?:0|[1-9]\d*)\.(?:0|[1-9]\d*)\.(?:0|[1-9]\d*)(?:-[\da-z-]+(?:\.[\da-z-]+)*)?(?:\+[\da-z-]+(?:\.[\da-z-]+)*)?\b$/i;

/**
 * Check if value is a valid version (according to semver 2.0.0)
 *
 * @param {*} value
 *
 * @returns {Boolean}
 */
function isObject(value) {
    return isString(value) && regexMatchSemver.test(value);
}

export default isObject;
//# sourceMappingURL=isSemver.js.map
