/**! @qoopido/validator 1.3.1 | https://github.com/dlueth/qoopido | (c) 2021 Dirk Lueth */
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof (provide || define) === 'function' && (provide || define).amd ? (provide || define)(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['@qoopido/validator'] = {}));
}(this, (function (exports) { 'use strict';

    /**
     * Check if value is of a certain type
     *
     * @param {*} value
     * @param {String} type
     *
     * @returns {Boolean}
     */
    function isTypeof(value, type) {
        return typeof value === type;
    }

    /**
     * Check if value is of a certain type
     *
     * @param {*} value
     * @param {*} constructor
     *
     * @returns {Boolean}
     */
    function isInstanceof(value, constructor) {
        return value instanceof constructor;
    }

    /**
     * Check if value is a function
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isFunction(value) {
        return isTypeof(value, "function");
    }

    /**
     * Check if value is an array
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isArray(value) {
        return Array.isArray(value);
    }

    /**
     * Check if value is falsy
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isFalsy(value) {
        // eslint-disable-next-line eqeqeq
        return !value || (!isArray(value) && (value == "" || value == 0));
    }

    /**
     * Check if value is a string
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isString(value) {
        return isTypeof(value, "string") || isInstanceof(value, String);
    }

    /**
     * Check if value is an object
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isObject$1(value) {
        return !isFalsy(value) && isTypeof(value, "object");
    }

    /**
     * Check if value is a positive integer
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isPositiveInteger(value) {
        return 0 === value % (!isNaN(parseFloat(value)) && 0 <= ~~value);
    }

    var regexMatchSemver =
        /^\bv?(?:0|[1-9]\d*)\.(?:0|[1-9]\d*)\.(?:0|[1-9]\d*)(?:-[\da-z-]+(?:\.[\da-z-]+)*)?(?:\+[\da-z-]+(?:\.[\da-z-]+)*)?\b$/i;

    /**
     * Check if value is a valid version (according to semver 2.0.0)
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isObject(value) {
        return isString(value) && regexMatchSemver.test(value);
    }

    /**
     * Check if value is transferable
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isTransferable(value) {
        return (
            ("ArrayBuffer" in self && value instanceof ArrayBuffer) ||
            ("MessagePort" in self && value instanceof MessagePort) ||
            ("ImageBitmap" in self && value instanceof ImageBitmap)
        );
    }

    /**
     * Check if value is a RegExp
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isRegExp(value) {
        return isInstanceof(value, RegExp);
    }

    /**
     * Check if value is thenable
     *
     * @param {*} value
     *
     * @returns {Boolean}
     */
    function isThenable(value) {
        return !isFalsy(value) && isFunction(value.then);
    }

    exports.isArray = isArray;
    exports.isFalsy = isFalsy;
    exports.isFunction = isFunction;
    exports.isInstanceof = isInstanceof;
    exports.isObject = isObject$1;
    exports.isPositiveInteger = isPositiveInteger;
    exports.isRegExp = isRegExp;
    exports.isSemver = isObject;
    exports.isString = isString;
    exports.isThenable = isThenable;
    exports.isTransferable = isTransferable;
    exports.isTypeof = isTypeof;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=index.js.map
